@@ -3,7 +3,7 @@
 from pages import settings
 from pages.models import Page, Content
 from pages.utils import get_placeholders
-from pages.http import auto_render, get_language_from_request
+from pages.phttp import get_language_from_request
 from pages.permissions import PagePermission
 
 from django.shortcuts import get_object_or_404, render_to_response
@@ -23,7 +23,7 @@ def change_status(request, page_id):
         page.status = int(request.POST['status'])
         page.invalidate()
         page.save()
-        return HttpResponse(unicode(page.status))
+        return HttpResponse(str(page.status))
     raise Http404
 change_status = staff_member_required(change_status)
 
