@@ -106,6 +106,7 @@ class PlaceholderNode(template.Node):
         These values should be thread safe and don't change between calls."""
         self.page = page or 'current_page'
         self.name = name
+        self.ctype = name.replace(" ", "_")
         if widget:
             self.widget = widget
         self.parsed = parsed
@@ -249,7 +250,7 @@ def get_filename(page, placeholder, data):
     filename = os.path.join(
         settings.PAGE_UPLOAD_ROOT,
         'page_' + str(page.id),
-        placeholder.name + '-' + str(time.time()) + '-' + data.name
+        placeholder.ctype + '-' + str(time.time()) + '-' + data.name
     )
     return filename
 
