@@ -538,7 +538,7 @@ class FunctionnalTestCase(TestCase):
         # Make sure we're in french
         response = c.get('/admin/pages/page/')
         self.assertEqual(response.status_code, 200)
-        self.assertTrue('Auteur' in response.content)
+        self.assertTrue(b'Auteur' in response.content)
 
         # Create some pages (taken from test_tree_admin_interface)
         page_data = self.get_new_page_data()
@@ -583,7 +583,7 @@ class FunctionnalTestCase(TestCase):
             {'position':'first-child', 'target':root_page.id})
 
         # Make sure the content response we got was in french
-        self.assertTrue('Auteur' in response.content)
+        self.assertTrue(b'Auteur' in response.content)
 
 
     def test_view_context(self):
@@ -887,3 +887,18 @@ class FunctionnalTestCase(TestCase):
 
         self.assertContains(response, 'english-slug')
         self.assertContains(response, 'french-slug')
+        
+    
+    def test_fileinput_in_admin(self):
+        """Test that a page can edited via the admin."""
+        c = self.get_admin_client()
+        c.login(username='batiste', password='b')
+        
+        page = self.new_page(content={'slug': 'just-a-test', 'file':'some file'})
+        page.template = 'pages/tests/fileinput.html'
+        page.save()
+
+        response = c.get('/admin/pages/page/%d/' % page.id)
+        self.assertEqual(response.status_code, 200)
+        self.assertContains(response, 'some file')
+
