@@ -5,6 +5,7 @@ from django.template import RequestContext, TemplateDoesNotExist
 from django.core.files.uploadedfile import SimpleUploadedFile
 from django.template import loader
 from pages.placeholders import PlaceholderNode, get_filename
+from pages.utils import get_placeholders
 
 import django
 import six
@@ -58,12 +59,25 @@ class RegressionTestCase(TestCase):
     def test_bug_152(self):
         """Test bug 152
         http://code.google.com/p/django-page-cms/issues/detail?id=152"""
-        from pages.utils import get_placeholders
         self.assertEqual(
             str(get_placeholders('pages/tests/test1.html')),
             "[<Placeholder Node: body>]"
         )
 
+    def test_bug_block_super(self):
+        """{{ block.super }} doesn't work"""
+        self.assertEqual(
+            str(get_placeholders('pages/tests/block2.html')),
+            "[<Placeholder Node: body>, <Placeholder Node: body2>]"
+        )
+
+    def test_bug_block_without_super(self):
+        """Without the block the placeholder should not be there"""
+        self.assertEqual(
+            str(get_placeholders('pages/tests/block3.html')),
+            "[<Placeholder Node: test>]"
+        )
+
     def test_bug_162(self):
         """Test bug 162
         http://code.google.com/p/django-page-cms/issues/detail?id=162"""
@@ -207,6 +221,17 @@ class RegressionTestCase(TestCase):
             'fr'
         )
 
+    def test_placeholder_name_space_bug(self):
+        """Cache key cannot us space."""
+        from pages.placeholders import PlaceholderNode
+        page = self.new_page()
+        placeholder = PlaceholderNode('test space', page=page)
+        placeholder.save(page, 'fr-ch', 'fr', True)
+        self.assertEqual(
+            Content.objects.get_content(page, 'fr-ch', 'test space'),
+            'fr'
+        )
+
     def test_pages_dynamic_tree_menu_bug(self):
         """
         Test a bug with the dynamic tree template tag doesn't occur anymore.
