@@ -10,6 +10,7 @@ from django.template import loader, Context
 from django.core.management.base import CommandError
 from django.utils.translation import ugettext_lazy as _
 from django.utils import timezone
+from django import template
 
 import re
 from datetime import datetime
@@ -19,7 +20,6 @@ def get_now():
         return datetime.utcnow().replace(tzinfo=timezone.utc)
     else:
         return datetime.now()
-        
 
 def get_placeholders(template_name):
     """Return a list of PlaceholderNode found in the given template.
@@ -33,7 +33,27 @@ def get_placeholders(template_name):
 
     plist, blist = [], []
     _placeholders_recursif(temp.nodelist, plist, blist)
-    return plist
+
+    previous = {}
+    block_to_remove = []
+    for block in blist:
+        if block.name in previous:
+            if not hasattr(block, 'has_super_var'):
+                block_to_remove.append(previous[block.name])
+        previous[block.name] = block
+
+    def keep(p):
+        return not p.found_in_block in block_to_remove
+
+    placeholders = [p for p in plist if keep(p)]
+    names = []
+    pfiltered = []
+    for p in placeholders:
+        if p.ctype not in names:
+            pfiltered.append(p)
+            names.append(p.ctype)
+
+    return pfiltered
 
 
 def _placeholders_recursif(nodelist, plist, blist):
@@ -42,8 +62,24 @@ def _placeholders_recursif(nodelist, plist, blist):
     # I needed to do this lazy import to compile the documentation
     from django.template.loader_tags import BlockNode
 
+    if len(blist):
+        block = blist[-1]
+    else:
+        block = None
+
     for node in nodelist:
 
+        if isinstance(node, BlockNode):
+            if node not in blist:
+                blist.append(node)
+            if not block:
+                block = node
+
+        if block:
+            if isinstance(node, template.VariableNode):
+                if(node.filter_expression.var.var == u'block.super'):
+                    block.has_super_var = True
+
         # extends node?
         if hasattr(node, 'parent_name'):
             _placeholders_recursif(node.get_parent(Context()).nodelist,
@@ -54,37 +90,21 @@ def _placeholders_recursif(nodelist, plist, blist):
 
         # Is it a placeholder?
         if hasattr(node, 'page') and hasattr(node, 'parsed') and \
-                hasattr(node, 'as_varname') and hasattr(node, 'name'):
-            already_in_plist = False
-            for placeholder in plist:
-                if placeholder.name == node.name:
-                    already_in_plist = True
-            if not already_in_plist:
-                if len(blist):
-                    node.found_in_block = blist[len(blist) - 1]
-                plist.append(node)
+            hasattr(node, 'as_varname') and hasattr(node, 'name'):
+            if block:
+                node.found_in_block = block
+            plist.append(node)
             node.render(Context())
 
         for key in ('nodelist', 'nodelist_true', 'nodelist_false'):
-            if isinstance(node, BlockNode):
-                # delete placeholders found in a block of the same name
-                offset = 0
-                _plist = [(i, v) for i, v in enumerate(plist)]
-                for index, pl in _plist:
-                    if pl.found_in_block and \
-                            pl.found_in_block.name == node.name \
-                            and pl.found_in_block != node:
-                        del plist[index - offset]
-                        offset += 1
-                blist.append(node)
 
             if hasattr(node, key):
                 try:
                     _placeholders_recursif(getattr(node, key), plist, blist)
                 except:
                     pass
-            if isinstance(node, BlockNode):
-                blist.pop()
+
+
 
 def normalize_url(url):
     """Return a normalized url with trailing and without leading slash.
